@@ -33,6 +33,14 @@ class results_analysis():
         self.labels = labels
         self.patients1 = [str(self.labels[x]) for x in self.solution[1][0]]
         self.patients2 = [str(self.labels[x]) for x in self.solution[1][1]]
+        #check for intersection of genes
+        isec= set(solution[0][0]).intersection(set(solution[0][1]))
+        if len(isec)>0:
+            solution[0][0] = list(set(solution[0][0]).difference(isec))
+            solution[0][1] = list(set(solution[0][1]).difference(isec))
+            self.isec = list(isec)
+        else:
+            self.isec = []
         self.genes1 = [str(self.labels[x]) for x in self.solution[0][0]]
         self.genes2 = [str(self.labels[x]) for x in self.solution[0][1]]
         self.convert = convert
@@ -101,10 +109,21 @@ class results_analysis():
 
         all_genes_entr = self.genes1 + self.genes2
         all_genes = self.solution[0][0] + self.solution[0][1]
+        if len(self.isec)>0:
+            isec_entr = [str(self.labels[x]) for x in self.isec]
+            all_genes_entr = all_genes_entr + isec_entr
+            all_genes = all_genes + self.isec
+
         if self.convert:
             genes1_name = [self.mapping[x] for x in self.genes1]
             genes2_name = [self.mapping[x] for x in self.genes2]
-            all_genes_names = genes1_name + genes2_name
+            if len(self.isec) > 0:
+                isec_name = [self.mapping[x] for x in isec_entr]
+                all_genes_names = genes1_name + genes2_name + isec_name
+            else:
+
+                all_genes_names = genes1_name + genes2_name
+
 
         # relabel expression matrix and the graph to the actual patients ids and gene names
         G_small = nx.subgraph(G, all_genes)
@@ -121,9 +140,14 @@ class results_analysis():
         if self.convert:
             nl1 = genes1_name
             nl2 = genes2_name
+            if len(self.isec) >0:
+                isec = isec_name
         else:
             nl1 = self.genes1
             nl2 = self.genes2
+            if len(self.isec) >0:
+                isec = isec_entr
+
         means1 = list(np.mean(GE_small[self.patients1].loc[nl1], axis=1) - np.mean(
             GE_small[self.patients2].loc[nl1], axis=1).values)
         means2 = list(np.mean(GE_small[self.patients1].loc[nl2], axis=1) - np.mean(
@@ -147,6 +171,11 @@ class results_analysis():
                                      vmin=vmin, vmax=vmax, cmap=cmap, node_shape="s")
         nc2 = nx.draw_networkx_nodes(G_small, nodelist = nl2, pos=pos, node_color=means2, node_size=1700, alpha=.7,
                                      vmin=vmin, vmax=vmax, cmap=cmap, node_shape="^")
+        if len(self.isec)>0:
+            nc3 = nx.draw_networkx_nodes(G_small, nodelist = isec, pos=pos, node_color="r", node_size=1700, alpha=.7,
+                                         vmin=vmin, vmax=vmax, cmap=cmap, node_shape="o")
+            print(f'node(s) {isec} intersect between clusters')
+
         nx.draw_networkx_labels(G_small, pos, font_size=22, font_weight="heavy")
         plt.colorbar(nc1)
         plt.axis('off')
@@ -175,16 +204,29 @@ class results_analysis():
                 print("WARNING: Patients ids in true_labels do not match, comparision wil not be performed")
                 true_labels = None
 
-        all_genes_entr = self.genes1 + self.genes2
-        all_genes = self.solution[0][0] + self.solution[0][1]
+        all_genes = self.solution[0][0] + self.solution[0][1] + self.isec
+
         if self.convert:
             genes1_name = [self.mapping[x] for x in self.genes1]
             genes2_name = [self.mapping[x] for x in self.genes2]
-            all_genes_names = genes1_name + genes2_name
+            if len(self.isec) > 0:
+                isec_entr = [str(self.labels[x]) for x in self.isec]
+
+                isec_name = [self.mapping[x] for x in isec_entr]
+                all_genes_names = genes1_name + genes2_name + isec_name
+            else:
+
+                all_genes_names = genes1_name + genes2_name
         else:
             genes1_name = self.genes1
             genes2_name = self.genes2
-            all_genes_names = genes1_name + genes2_name
+            if len(self.isec) > 0:
+                isec_entr = [str(self.labels[x]) for x in self.isec]
+                all_genes_names = genes1_name + genes2_name + isec_entr
+            else:
+
+                all_genes_names = genes1_name + genes2_name
+
 
         # relabel expression matrix and the graph to the actual patients ids and gene names
         GE_small = GE[self.solution[1][0] + self.solution[1][1]].loc[all_genes]
@@ -234,13 +276,13 @@ class results_analysis():
         grouping_g = pd.DataFrame(grouping_g, index=g_num)
         grouping_g.columns = [" "]
         species = grouping_g[" "]
-        lut = {1: '#4FB6D3', 2: '#22863E'}
+        lut = {1: '#4FB6D3', 2: '#22863E', 3: "r"}
         col_colors = species.map(lut)
 
         plt.rc('font', size=5)  # controls default text sizes
         plt.rc('axes', titlesize=20)  # fontsize of the axes title
         plt.rc('axes', labelsize=20)  # fontsize of the x and y labels
-        plt.rc('xtick', labelsize=20)  # fontsize of the tick labels
+        plt.rc('xtick', labelsize=15)  # fontsize of the tick labels
         plt.rc('ytick', labelsize=10)  # fontsize of the tick labels
         plt.rc('legend', fontsize=20)
 
@@ -255,7 +297,9 @@ class results_analysis():
                 values = ["true class1", "true class2", "cluster1", "cluster2"]
             else:
                 values = [class_names[0], class_names[1], "cluster1", "cluster2"]
-            colors = ['#F3FF33', 'm', '#4FB6D3', '#22863E']
+            if len(self.isec) >0:
+                values = values + ["shared gene"]
+            colors = ['#F3FF33', 'm', '#4FB6D3', '#22863E', "r"]
             for i in range(len(values)):
                 l = values[i]
                 c = colors[i]
@@ -271,7 +315,9 @@ class results_analysis():
             # g.cax.set_visible(False)
 
             values = ["cluster1", "cluster2"]
-            colors = ['#4FB6D3', '#22863E']
+            if len(self.isec) >0:
+                values = values + ["shared gene"]
+            colors = ['#4FB6D3', '#22863E', "r"]
             for i in range(len(values)):
                 l = values[i]
                 c = colors[i]
